"use strict";

var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
require("@testing-library/jest-dom");
var _index = require("../index");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _button;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
const TEST_STRING = 'test';
const renderBadge = (props = {
  count: 100
}) => {
  return (0, _react.render)((0, _jsxRuntime.jsx)(_index.Badge, {
    ...props,
    children: _button || (_button = (0, _jsxRuntime.jsx)("button", {
      type: "button",
      children: TEST_STRING
    }))
  }));
};
describe('<Badge />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should be accessible', async () => {
    const _renderBadge = renderBadge(),
      container = _renderBadge.container;
    const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
    expect(axeCheck).toBe(true);
  });
  it('should show the count', () => {
    const _renderBadge2 = renderBadge({
        count: 100
      }),
      container = _renderBadge2.container;
    expect(container).toHaveTextContent('100');
  });
  it('should truncate the count via countUntil', async () => {
    renderBadge({
      count: 100,
      countUntil: 100
    });
    const truncatedCount = await _react.screen.findByText('99 +');
    expect(truncatedCount).toBeVisible();
  });
  it('should change position based on the placement prop', () => {
    const countOffset = '5px';
    const EXPECTED_PROP_VALUE = 'calc(-1 * 5px)';
    const _renderBadge3 = renderBadge({
        placement: 'bottom start',
        themeOverride: {
          countOffset
        }
      }),
      container = _renderBadge3.container;
    const badge = container.querySelector('[class*=block][class*=badge]');
    const badgeStyle = badge && getComputedStyle(badge);
    expect(badge).not.toBeNull();
    expect(badgeStyle).toHaveProperty('bottom', EXPECTED_PROP_VALUE);
    expect(badgeStyle).toHaveProperty('inset-inline-start', EXPECTED_PROP_VALUE);
  });
  it('should not render a wrapper for a standalone Badge', () => {
    const _renderBadge4 = renderBadge({
        as: 'li',
        standalone: true
      }),
      container = _renderBadge4.container;
    const liElement = container.querySelector('li');
    expect(liElement).toBeNull();
  });
  it('should render a wrapper for a NONE standalone Badge', () => {
    const _renderBadge5 = renderBadge({
        as: 'li',
        standalone: false
      }),
      container = _renderBadge5.container;
    const liElement = container.querySelector('li');
    expect(liElement).not.toBeNull();
  });
  it('should change its output via the formatOutput prop', () => {
    const formatOutput = formattedCount => {
      return `${formattedCount}!`;
    };
    renderBadge({
      count: 15,
      formatOutput
    });
    const badgeElement = _react.screen.getByText('15!');
    expect(badgeElement).toBeInTheDocument();
  });
  it('should render button child correctly', () => {
    const _renderBadge6 = renderBadge(),
      container = _renderBadge6.container;
    const childBtnElement = container.querySelector('button');
    expect(childBtnElement).toBeInTheDocument();
    expect(container).toHaveTextContent(TEST_STRING);
  });
  it('should call elementRef function', () => {
    const refMock = _vitest.vi.fn();
    const _renderBadge7 = renderBadge({
        elementRef: refMock
      }),
      container = _renderBadge7.container;
    expect(refMock).toHaveBeenCalledWith(container.firstChild);
  });
  it('should show the count when type is count', () => {
    const _renderBadge8 = renderBadge({
        count: 100,
        type: 'count'
      }),
      container = _renderBadge8.container;
    expect(container).toHaveTextContent('100');
  });
  it('should NOT show the count when type is notification', () => {
    const _renderBadge9 = renderBadge({
        count: 100,
        type: 'notification'
      }),
      container = _renderBadge9.container;
    expect(container).not.toHaveTextContent('100');
  });
});